"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateTagTypes = exports.generateEndpointDefinition = exports.generateCreateApiCall = exports.generateImportNode = exports.generateObjectProperties = void 0;
const typescript_1 = __importDefault(require("typescript"));
const factory_1 = require("./utils/factory");
const defaultEndpointBuilder = factory_1.factory.createIdentifier('build');
function generateObjectProperties(obj) {
    return Object.entries(obj)
        .filter(([_, v]) => v)
        .map(([k, v]) => factory_1.factory.createPropertyAssignment(factory_1.factory.createIdentifier(k), v));
}
exports.generateObjectProperties = generateObjectProperties;
function generateImportNode(pkg, namedImports, defaultImportName) {
    return factory_1.factory.createImportDeclaration(undefined, factory_1.factory.createImportClause(false, defaultImportName !== undefined ? factory_1.factory.createIdentifier(defaultImportName) : undefined, factory_1.factory.createNamedImports(Object.entries(namedImports).map(([propertyName, { name, isTypeOnly }]) => factory_1.factory.createImportSpecifier(isTypeOnly, name === propertyName ? undefined : factory_1.factory.createIdentifier(propertyName), factory_1.factory.createIdentifier(name))))), factory_1.factory.createStringLiteral(pkg));
}
exports.generateImportNode = generateImportNode;
function generateCreateApiCall({ endpointBuilder = defaultEndpointBuilder, endpointDefinitions, }) {
    const injectEndpointsObjectLiteralExpression = factory_1.factory.createObjectLiteralExpression(generateObjectProperties({
        endpoints: factory_1.factory.createArrowFunction(undefined, undefined, [
            factory_1.factory.createParameterDeclaration(undefined, undefined, endpointBuilder, undefined, undefined, undefined),
        ], undefined, factory_1.factory.createToken(typescript_1.default.SyntaxKind.EqualsGreaterThanToken), factory_1.factory.createParenthesizedExpression(endpointDefinitions)),
        overrideExisting: factory_1.factory.createFalse(),
    }), true);
    return factory_1.factory.createCallExpression(factory_1.factory.createPropertyAccessExpression(factory_1.factory.createIdentifier('api'), factory_1.factory.createIdentifier('injectEndpoints')), undefined, [injectEndpointsObjectLiteralExpression]);
}
exports.generateCreateApiCall = generateCreateApiCall;
function generateEndpointDefinition({ operationName, Response, QueryArg, queryFn, }) {
    return factory_1.factory.createVariableStatement([factory_1.factory.createToken(typescript_1.default.SyntaxKind.ExportKeyword)], factory_1.factory.createVariableDeclarationList([
        factory_1.factory.createVariableDeclaration(factory_1.factory.createIdentifier(operationName), undefined, undefined, factory_1.factory.createArrowFunction(undefined, undefined, [
            factory_1.factory.createParameterDeclaration(undefined, undefined, factory_1.factory.createIdentifier('args'), undefined, QueryArg, undefined),
            factory_1.factory.createParameterDeclaration(undefined, undefined, factory_1.factory.createIdentifier('options'), factory_1.factory.createToken(typescript_1.default.SyntaxKind.QuestionToken), factory_1.factory.createTypeReferenceNode(factory_1.factory.createIdentifier('Options'), undefined), undefined),
        ], undefined, factory_1.factory.createToken(typescript_1.default.SyntaxKind.EqualsGreaterThanToken), factory_1.factory.createBlock([
            factory_1.factory.createReturnStatement(factory_1.factory.createCallExpression(factory_1.factory.createIdentifier('apiClient'), [Response], [queryFn, factory_1.factory.createIdentifier('options')])),
        ], true))),
    ], typescript_1.default.NodeFlags.Const));
}
exports.generateEndpointDefinition = generateEndpointDefinition;
function generateTagTypes({ addTagTypes }) {
    return factory_1.factory.createVariableStatement([factory_1.factory.createModifier(typescript_1.default.SyntaxKind.ExportKeyword)], factory_1.factory.createVariableDeclarationList([
        factory_1.factory.createVariableDeclaration(factory_1.factory.createIdentifier('addTagTypes'), undefined, undefined, factory_1.factory.createAsExpression(factory_1.factory.createArrayLiteralExpression(addTagTypes.map((tagType) => factory_1.factory.createStringLiteral(tagType)), true), factory_1.factory.createTypeReferenceNode(factory_1.factory.createIdentifier('const'), undefined))),
    ], typescript_1.default.NodeFlags.Const));
}
exports.generateTagTypes = generateTagTypes;
//# sourceMappingURL=codegen.js.map